{ config, lib, pkgs, ... }:

let
  cfg = config.r6d.config-generator;
  computers = config.r6d.computers;
  profiles = config.r6d.profiles;
  mkIf = lib.mkIf;
in

{
  imports = [                   # applications :
    # commandées par config-generator
    ./activation-manuelle/xmonad/xmonad.nix      # gestionnaire de fenêtres xmonad
  ];

  # Paquets
  environment.systemPackages = with pkgs; mkIf profiles.isDesktop [

    # A trier
    cowsay
    fgallery        # générateur de gallerie statique http://www.thregr.org/~wavexx/software/fgallery/
    taskwarrior     # gestionnaire de tâches en console
    xclip           # manipulation du clipboard X depuis la console
  ];

  # Polices supplémentaires
  fonts.fonts = with pkgs; mkIf profiles.isDesktop [
    fira            # police créée pour Firefox
    fira-code       # idem fira-mono + ligatures pour la programmation
    fira-mono       # dérivée de fira en monospace
    hack-font       # police monospace créée explicitement pour coder
    hasklig         # police dérivée de source-code-pro mais avec des ligatures
  ];

  nixpkgs.config.packageOverrides = pkgs: {
    clawsMail = pkgs.clawsMail.override {
      enablePluginFancy = true;
      enablePluginPdf = true;
      enablePluginRavatar = true;
      enablePluginSmime = true;
      enablePluginVcalendar = true;
      enableSpellcheck = true;
    };
    mumble = pkgs.mumble.override { pulseSupport = true; };
  };

  # Paquets avec setuid root
  security.wrappers = {
    # pour le montage des media amovibles
    devmon.source = "${pkgs.udevil}/bin/devmon";
    udevil.source = "${pkgs.udevil}/bin/udevil";
  };
}
